summaryrefslogtreecommitdiff
path: root/src/modules/m_check.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_check.cpp')
-rw-r--r--src/modules/m_check.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/modules/m_check.cpp b/src/modules/m_check.cpp
index cabfd02bc..8316b09fe 100644
--- a/src/modules/m_check.cpp
+++ b/src/modules/m_check.cpp
@@ -20,9 +20,9 @@
*/
#include "inspircd.h"
/* $ModDesc: Provides the /check command to retrieve information on a user, channel, or IP address */
/** Handle /CHECK
*/
@@ -288,7 +288,7 @@ class ModuleCheck : public Module
Version GetVersion()
{
- return Version("CHECK command, view user/channel details", VF_VENDOR|VF_OPTCOMMON);
+ return Version("CHECK command, view user, channel, IP address or hostname information", VF_VENDOR|VF_OPTCOMMON);
}
};
@@ -20,9 +20,9 @@
*/
-#include "inspircd.h"
+/* $ModDesc: Provides the /CHECK command to retrieve information on a user, channel, hostname or IP address */
-/* $ModDesc: Provides the /check command to retrieve information on a user, channel, or IP address */
+#include "inspircd.h"
/** Handle /CHECK
*/